!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 07/2017                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2018-11-28 19:55             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 1248
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: VFaF0 = 4
  integer, parameter :: VFaF1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVS0 = 7
  integer, parameter :: UUaS0 = 8
  integer, parameter :: UUaV0 = 9
  integer, parameter :: USUa0 = 10
  integer, parameter :: SUUa0 = 11
  integer, parameter :: VVSS0 = 12
  integer, parameter :: FaF0 = 13
  integer, parameter :: FaF1 = 14
  integer, parameter :: FFaV0 = 15
  integer, parameter :: FFaV1 = 16
  integer, parameter :: VVV0 = 17
  integer, parameter :: FSFa0 = 18
  integer, parameter :: FSFa1 = 19
  integer, parameter :: FSFa2 = 20
  integer, parameter :: VVVV0 = 21
  integer, parameter :: VUaU0 = 22
  integer, parameter :: FaVF0 = 23
  integer, parameter :: FaVF1 = 24
  integer, parameter :: UaVU0 = 25
  integer, parameter :: VSVS0 = 26
  integer, parameter :: FVFa0 = 27
  integer, parameter :: FVFa1 = 28
  integer, parameter :: UaSU0 = 29
  integer, parameter :: VV0 = 30
  integer, parameter :: VV1 = 31
  integer, parameter :: VV2 = 32
  integer, parameter :: VV3 = 33
  integer, parameter :: VV4 = 34
  integer, parameter :: VV5 = 35
  integer, parameter :: SVSV0 = 36
  integer, parameter :: FaFS0 = 37
  integer, parameter :: FaFS1 = 38
  integer, parameter :: FaFS2 = 39
  integer, parameter :: FaFV0 = 40
  integer, parameter :: FaFV1 = 41
  integer, parameter :: SSSS0 = 42
  integer, parameter :: VS0 = 43
  integer, parameter :: SFFa0 = 44
  integer, parameter :: SFFa1 = 45
  integer, parameter :: SFFa2 = 46
  integer, parameter :: VUUa0 = 47
  integer, parameter :: SFaF0 = 48
  integer, parameter :: SFaF1 = 49
  integer, parameter :: SFaF2 = 50
  integer, parameter :: SVV0 = 51
  integer, parameter :: FaSF0 = 52
  integer, parameter :: FaSF1 = 53
  integer, parameter :: FaSF2 = 54
  integer, parameter :: SVS0 = 55
  integer, parameter :: FFa0 = 56
  integer, parameter :: FFa1 = 57
  integer, parameter :: VSS0 = 58
  integer, parameter :: VSV0 = 59
  integer, parameter :: SS0 = 60
  integer, parameter :: SS1 = 61
  integer, parameter :: SS2 = 62
  integer, parameter :: SSVV0 = 63
  integer, parameter :: SSV0 = 64
  integer, parameter :: SV0 = 65
  integer, parameter :: SSS0 = 66
  integer, parameter :: UVUa0 = 67
  integer, parameter :: VSSV0 = 68
  integer, parameter :: UaUS0 = 69
  integer, parameter :: VFFa0 = 70
  integer, parameter :: VFFa1 = 71
  integer, parameter :: SUaU0 = 72
  integer, parameter :: UaUV0 = 73
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "sq2/2"
  complex(dp), parameter :: c3 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c4 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c4f = "i_*sq2/2"
  complex(dp), parameter :: c5 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c5f = "-i_*sq2/2"
  complex(dp), parameter :: c6 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c6f = "-1/2"
  complex(dp), parameter :: c7 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c7f = "1/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:73) :: lorentz_rank = (/0, 0, 0, 1, 1, 0, 0, 0, 1, 0, 0 &
                                             , 0, -1, -1, 0, 0, 1, 1, 1, 1, 0, &
                                             1, 1, 1, 1, 0, 1, 1, 0, -1, -1, -1&
                                             , -1, -1, -1, 0, 0, 0, 0, 0, 0, 0 &
                                             , -1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1&
                                             , 1, 1, -1, -1, 1, 0, -1, -1, -1, &
                                             0, 1, -1, 0, 1, 0, 0, 1, 1, 0, 1/)
  integer, dimension(1:73) :: recola_base = (/9, 5, 7, 53, 58, -2, 2, 1, 161, 1&
                                            , 1, -4, 0, 0, 17, 15, 12, 25, 21, &
                                            27, -11, 162, 51, 57, 166, -3, 35, &
                                            31, 1, 0, 0, 0, 0, 0, 0, -14, 6, 8 &
                                            , 10, 16, 18, -1, 0, 23, 26, 28,   &
                                            163, 43, 48, 46, 13, 41, 47, 45, 3 &
                                            , 0, 0, 4, 14, 0, 0, 0, -12, 11, 0 &
                                            , 1, 165, -13, 1, 36, 33, 1, 164/)
  integer, dimension(1:73) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0/)
  character(len=*), parameter :: model_timestamp = "Wed Nov 28 19:42:35 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(2477)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 1048, check)
      call createCurrent(P_t, P_tAnti, P_g, 247, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 74, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 327, check)
      call createCurrent(P_WPlus, P_H, P_H, P_WMinus, 371, check)
      call createCurrent(P_G0, P_H, P_A, 1084, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 1037, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 712, check)
      call createCurrent(P_t, P_tAnti, P_A, 967, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 512, check)
      call createCurrent(P_H, P_t, P_tAnti, 826, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 662, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 810, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 44, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghWp, 1020, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 534, check)
      call createCurrent(P_Z, P_bAnti, P_b, 429, check)
      call createCurrent(P_H, P_tauPlus, P_tauMinus, 149, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 516, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 633, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 609, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 1021, check)
      call createCurrent(P_Z, P_GPlus, P_H, P_WMinus, 92, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_A, 1143, check)
      call createCurrent(P_H, P_H, P_A, P_Z, 1059, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_A, 990, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 786, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, 739, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 912, check)
      call createCurrent(P_ePlus, P_eMinus, P_H, 785, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 626, check)
      call createCurrent(P_G0, P_A, P_G0, P_A, 1224, check)
      call createCurrent(P_muPlus, P_muMinus, 1096, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 451, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 924, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 137, check)
      call createCurrent(P_G0, P_uAnti, P_u, 248, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_A, 418, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 141, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 681, check)
      call createCurrent(P_A, P_c, P_cAnti, 809, check)
      call createCurrent(P_s, P_sAnti, P_H, 711, check)
      call createCurrent(P_t, P_tAnti, P_G0, 907, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 1226, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 1208, check)
      call createCurrent(P_H, P_G0, P_G0, 323, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_Z, 87, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 871, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 218, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 648, check)
      call createCurrent(P_A, P_uAnti, P_u, 471, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 815, check)
      call createCurrent(P_g, P_cAnti, P_c, 467, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 643, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 26, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 80, check)
      call createCurrent(P_G0, P_A, P_Z, P_G0, 1098, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 839, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 469, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 853, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, 58, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 794, check)
      call createCurrent(P_H, P_H, 1056, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 1159, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 392, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 222, check)
      call createCurrent(P_sAnti, P_g, P_s, 238, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 683, check)
      call createCurrent(P_G0, P_b, P_bAnti, 908, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 1036, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 76, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 379, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 570, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 407, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 110, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 727, check)
      call createCurrent(P_A, P_dAnti, P_d, 54, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_H, 297, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 985, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 152, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_H, 755, check)
      call createCurrent(P_sAnti, P_s, 1134, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 824, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 916, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 302, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 399, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, P_H, 484, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 83, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 979, check)
      call createCurrent(P_H, P_ghZAnti, P_ghZ, 583, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 847, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 770, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 563, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, 63, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_Z, 511, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 340, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 1019, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 93, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 13, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 851, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 1099, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 230, check)
      call createCurrent(P_Z, P_H, P_A, P_H, 1054, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_Z, 1001, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 919, check)
      call createCurrent(P_muMinus, P_muPlus, P_H, 720, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 1168, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 88, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 673, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 966, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 1210, check)
      call createCurrent(P_H, P_WPlus, P_A, P_GMinus, 332, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, P_H, 930, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 86, check)
      call createCurrent(P_dAnti, P_d, 1144, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 437, check)
      call createCurrent(P_cAnti, P_G0, P_c, 891, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 504, check)
      call createCurrent(P_u, P_uAnti, P_G0, 234, check)
      call createCurrent(P_s, P_A, P_sAnti, 52, check)
      call createCurrent(P_Z, P_A, P_A, P_A, 1155, check)
      call createCurrent(P_GMinus, P_GPlus, 1083, check)
      call createCurrent(P_tauPlus, P_tauMinus, 1137, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 212, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, P_H, 329, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 934, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 1218, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 1185, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 431, check)
      call createCurrent(P_Z, P_Z, P_A, P_A, 1217, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_A, 1117, check)
      call createCurrent(P_Z, P_H, P_WPlus, P_GMinus, 341, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 661, check)
      call createCurrent(P_H, P_H, P_Z, P_Z, 223, check)
      call createCurrent(P_H, P_G0, P_A, 1058, check)
      call createCurrent(P_WPlus, P_A, P_H, P_GMinus, 995, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 499, check)
      call createCurrent(P_A, P_nu_tau, P_nu_tauAnti, 1119, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 963, check)
      call createCurrent(P_cAnti, P_g, P_c, 289, check)
      call createCurrent(P_WMinus, P_H, P_Z, P_GPlus, 73, check)
      call createCurrent(P_A, P_cAnti, P_c, 877, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 159, check)
      call createCurrent(P_G0, P_H, P_Z, 108, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 261, check)
      call createCurrent(P_A, P_G0, P_G0, P_A, 1161, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 1032, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 191, check)
      call createCurrent(P_Z, P_A, P_G0, P_G0, 1082, check)
      call createCurrent(P_Z, P_c, P_cAnti, 859, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 719, check)
      call createCurrent(P_G0, P_Z, P_G0, P_A, 1074, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 732, check)
      call createCurrent(P_WPlus, P_H, P_A, P_GMinus, 974, check)
      call createCurrent(P_d, P_g, P_dAnti, 345, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 803, check)
      call createCurrent(P_bAnti, P_b, P_g, 213, check)
      call createCurrent(P_cAnti, P_Z, P_c, 31, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_Z, 353, check)
      call createCurrent(P_Z, P_G0, P_G0, P_A, 1133, check)
      call createCurrent(P_g, P_tAnti, P_t, 428, check)
      call createCurrent(P_GPlus, P_GMinus, 1108, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 1233, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 792, check)
      call createCurrent(P_t, P_H, P_tAnti, 524, check)
      call createCurrent(P_cAnti, P_A, P_c, 603, check)
      call createCurrent(P_g, P_g, P_H, 1154, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 352, check)
      call createCurrent(P_muPlus, P_muMinus, P_H, 925, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 7, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 195, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 608, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 579, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 647, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 509, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 283, check)
      call createCurrent(P_Z, P_Z, P_Z, P_Z, 1163, check)
      call createCurrent(P_uAnti, P_u, P_H, 840, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 861, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 716, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 320, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 639, check)
      call createCurrent(P_H, P_H, P_Z, P_A, 1087, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_H, 233, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 895, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, 266, check)
      call createCurrent(P_t, P_Z, P_tAnti, 883, check)
      call createCurrent(P_H, P_tauMinus, P_tauPlus, 1047, check)
      call createCurrent(P_G0, P_dAnti, P_d, 210, check)
      call createCurrent(P_t, P_g, P_tAnti, 151, check)
      call createCurrent(P_H, P_g, P_H, P_g, 1200, check)
      call createCurrent(P_s, P_Z, P_sAnti, 829, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 538, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 969, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 977, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 782, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 129, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 756, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 284, check)
      call createCurrent(P_H, P_cAnti, P_c, 156, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 187, check)
      call createCurrent(P_bAnti, P_b, P_G0, 470, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 452, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, P_H, 927, check)
      call createCurrent(P_H, P_G0, P_H, P_G0, 306, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 549, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_Z, 89, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 209, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 1003, check)
      call createCurrent(P_nu_tau, P_A, P_nu_tauAnti, 1085, check)
      call createCurrent(P_H, P_H, P_GPlus, P_GMinus, 450, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 199, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 34, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 580, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 888, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 193, check)
      call createCurrent(P_G0, P_u, P_uAnti, 1044, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 427, check)
      call createCurrent(P_A, P_Z, P_Z, P_A, 1227, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 680, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 833, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 16, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 375, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 182, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 112, check)
      call createCurrent(P_u, P_A, P_uAnti, 669, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 356, check)
      call createCurrent(P_H, P_Z, P_GMinus, P_WPlus, 722, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 684, check)
      call createCurrent(P_H, P_g, P_g, 1178, check)
      call createCurrent(P_uAnti, P_G0, P_u, 799, check)
      call createCurrent(P_A, P_u, P_uAnti, 116, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_A, 2, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 180, check)
      call createCurrent(P_G0, P_c, P_cAnti, 625, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 1172, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 768, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 1222, check)
      call createCurrent(P_dAnti, P_d, P_Z, 41, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 443, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 1012, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 751, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 35, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 206, check)
      call createCurrent(P_b, P_bAnti, P_G0, 606, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 290, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 857, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 115, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 255, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 941, check)
      call createCurrent(P_g, P_H, P_H, P_g, 1240, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 834, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 525, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 763, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 1046, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 602, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 381, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_A, 1076, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, 929, check)
      call createCurrent(P_H, P_uAnti, P_u, 197, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 342, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 714, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 1029, check)
      call createCurrent(P_Z, P_G0, P_H, 992, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 968, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 884, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 897, check)
      call createCurrent(P_H, P_sAnti, P_s, 998, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 862, check)
      call createCurrent(P_A, P_A, P_H, 1191, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 503, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 457, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 192, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 400, check)
      call createCurrent(P_t, P_tAnti, P_H, 312, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 1212, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 667, check)
      call createCurrent(P_A, P_Z, P_Z, P_Z, 1202, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 272, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 144, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_A, 1067, check)
      call createCurrent(P_WPlus, P_Z, P_H, P_GMinus, 879, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 276, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 670, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 380, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 614, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 890, check)
      call createCurrent(P_sAnti, P_s, P_H, 315, check)
      call createCurrent(P_H, P_WMinus, P_H, P_WPlus, 708, check)
      call createCurrent(P_A, P_H, P_GMinus, P_WPlus, 42, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 547, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 693, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 644, check)
      call createCurrent(P_dAnti, P_d, P_A, 459, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 542, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 333, check)
      call createCurrent(P_d, P_A, P_dAnti, 540, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 980, check)
      call createCurrent(P_Z, P_uAnti, P_u, 133, check)
      call createCurrent(P_H, P_muMinus, P_muPlus, 721, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_A, 235, check)
      call createCurrent(P_Z, P_H, P_Z, 279, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 700, check)
      call createCurrent(P_G0, P_A, P_H, 1127, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_Z, 942, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 134, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_H, 706, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 160, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, 460, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 874, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, P_H, 983, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, 360, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 231, check)
      call createCurrent(P_GPlus, P_H, P_H, P_GMinus, 365, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 36, check)
      call createCurrent(P_dAnti, P_g, P_d, 220, check)
      call createCurrent(P_Z, P_A, P_Z, P_Z, 1219, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 99, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 1063, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 882, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 167, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 759, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 797, check)
      call createCurrent(P_nu_e, P_A, P_nu_eAnti, 1069, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 523, check)
      call createCurrent(P_c, P_cAnti, P_A, 723, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 243, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 171, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_H, 823, check)
      call createCurrent(P_H, P_GPlus, P_Z, P_WMinus, 22, check)
      call createCurrent(P_sAnti, P_s, P_A, 64, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 310, check)
      call createCurrent(P_s, P_sAnti, 1089, check)
      call createCurrent(P_H, P_ghWm, P_ghWmAnti, 250, check)
      call createCurrent(P_G0, P_Z, 1126, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 388, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 1031, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 913, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 1243, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 183, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 710, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 1215, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 498, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 576, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 265, check)
      call createCurrent(P_g, P_sAnti, P_s, 830, check)
      call createCurrent(P_tAnti, P_t, P_A, 48, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 483, check)
      call createCurrent(P_A, P_Z, P_H, P_H, 1068, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 554, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 107, check)
      call createCurrent(P_u, P_uAnti, P_H, 502, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 194, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 1207, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_Z, 988, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 1028, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 322, check)
      call createCurrent(P_nu_mu, P_A, P_nu_muAnti, 1123, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 1025, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 224, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 772, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_H, 520, check)
      call createCurrent(P_A, P_g, P_g, P_A, 1156, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 1024, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 412, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 472, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 319, check)
      call createCurrent(P_G0, P_bAnti, P_b, 957, check)
      call createCurrent(P_A, P_d, P_dAnti, 208, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 201, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 271, check)
      call createCurrent(P_g, P_A, P_g, P_A, 1187, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, 777, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 975, check)
      call createCurrent(P_cAnti, P_c, P_g, 326, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 678, check)
      call createCurrent(P_H, P_H, P_H, 690, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_A, 1142, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 444, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 1039, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 25, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 790, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, 1023, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 986, check)
      call createCurrent(P_dAnti, P_A, P_d, 446, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_A, 130, check)
      call createCurrent(P_A, P_A, P_A, P_Z, 1223, check)
      call createCurrent(P_A, P_H, P_H, P_A, 1152, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 863, check)
      call createCurrent(P_uAnti, P_u, 1110, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 1007, check)
      call createCurrent(P_A, P_g, P_A, P_g, 1234, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 902, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_Z, 435, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_Z, 455, check)
      call createCurrent(P_A, P_sAnti, P_s, 311, check)
      call createCurrent(P_tAnti, P_t, P_H, 432, check)
      call createCurrent(P_H, P_A, P_H, P_A, 1244, check)
      call createCurrent(P_g, P_g, P_A, P_A, 1153, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 812, check)
      call createCurrent(P_H, P_H, P_G0, P_G0, 142, check)
      call createCurrent(P_sAnti, P_A, P_s, 433, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 260, check)
      call createCurrent(P_A, P_G0, P_H, 1061, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 465, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 619, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 398, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, 55, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 166, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 5, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 1157, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 1149, check)
      call createCurrent(P_Z, P_b, P_bAnti, 497, check)
      call createCurrent(P_d, P_dAnti, P_Z, 430, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 776, check)
      call createCurrent(P_dAnti, P_H, P_d, 328, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 1145, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 501, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 185, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 267, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 1004, check)
      call createCurrent(P_H, P_GMinus, P_A, P_WPlus, 892, check)
      call createCurrent(P_A, P_G0, P_Z, P_G0, 1135, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_H, 636, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 637, check)
      call createCurrent(P_A, P_g, P_g, P_g, 1220, check)
      call createCurrent(P_Z, P_WPlus, P_H, P_GMinus, 819, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 1206, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 949, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 1102, check)
      call createCurrent(P_Z, P_dAnti, P_d, 850, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 1246, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 982, check)
      call createCurrent(P_GPlus, P_WMinus, 1073, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_H, 638, check)
      call createCurrent(P_tAnti, P_H, P_t, 173, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 397, check)
      call createCurrent(P_g, P_g, P_g, P_A, 1199, check)
      call createCurrent(P_A, P_nu_muAnti, P_nu_mu, 1060, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 449, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 47, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 717, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 959, check)
      call createCurrent(P_c, P_g, P_cAnti, 713, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_H, 866, check)
      call createCurrent(P_GMinus, P_A, P_H, P_WPlus, 15, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, 658, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 291, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 61, check)
      call createCurrent(P_c, P_cAnti, P_Z, 478, check)
      call createCurrent(P_H, P_H, P_WPlus, P_WMinus, 836, check)
      call createCurrent(P_A, P_b, P_bAnti, 30, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 773, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 744, check)
      call createCurrent(P_uAnti, P_u, P_g, 49, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 528, check)
      call createCurrent(P_g, P_g, P_H, P_H, 1166, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 921, check)
      call createCurrent(P_A, P_A, P_H, P_H, 1151, check)
      call createCurrent(P_c, P_Z, P_cAnti, 801, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 984, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 313, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 596, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 404, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 632, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 771, check)
      call createCurrent(P_s, P_g, P_sAnti, 246, check)
      call createCurrent(P_tAnti, P_t, 1120, check)
      call createCurrent(P_GMinus, P_H, P_A, P_WPlus, 613, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, 741, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 466, check)
      call createCurrent(P_sAnti, P_H, P_s, 705, check)
      call createCurrent(P_sAnti, P_G0, P_s, 359, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 822, check)
      call createCurrent(P_bAnti, P_H, P_b, 991, check)
      call createCurrent(P_H, P_A, P_Z, P_H, 1115, check)
      call createCurrent(P_dAnti, P_Z, P_d, 610, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 71, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 774, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 1022, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 394, check)
      call createCurrent(P_Z, P_u, P_uAnti, 493, check)
      call createCurrent(P_H, P_g, P_g, P_H, 1179, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 102, check)
      call createCurrent(P_Z, P_H, P_GPlus, P_WMinus, 278, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 148, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 488, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 738, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 318, check)
      call createCurrent(P_b, P_bAnti, P_A, 295, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 789, check)
      call createCurrent(P_A, P_G0, 1132, check)
      call createCurrent(P_H, P_H, P_WMinus, P_WPlus, 574, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_A, 657, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 654, check)
      call createCurrent(P_tAnti, P_t, P_Z, 217, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 588, check)
      call createCurrent(P_uAnti, P_u, P_G0, 835, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 43, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 11, check)
      call createCurrent(P_H, P_A, P_H, P_Z, 1125, check)
      call createCurrent(P_b, P_G0, P_bAnti, 954, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 124, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, 324, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 136, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 9, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 779, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 309, check)
      call createCurrent(P_H, P_bAnti, P_b, 964, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 178, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 29, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 1165, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 1180, check)
      call createCurrent(P_H, P_A, P_WMinus, P_GPlus, 769, check)
      call createCurrent(P_A, P_H, P_G0, 1111, check)
      call createCurrent(P_g, P_u, P_uAnti, 726, check)
      call createCurrent(P_H, P_GPlus, P_A, P_WMinus, 84, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 303, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_H, 935, check)
      call createCurrent(P_H, P_Z, P_WPlus, P_GMinus, 177, check)
      call createCurrent(P_uAnti, P_A, P_u, 1045, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 1175, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 1183, check)
      call createCurrent(P_A, P_A, P_Z, P_Z, 1197, check)
      call createCurrent(P_A, P_Z, P_A, P_A, 1188, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 993, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 981, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 808, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 377, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 1162, check)
      call createCurrent(P_Z, P_H, P_H, P_Z, 294, check)
      call createCurrent(P_G0, P_H, P_G0, 198, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 1016, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 20, check)
      call createCurrent(P_A, P_A, P_A, P_A, 1247, check)
      call createCurrent(P_H, P_Z, P_H, P_A, 1139, check)
      call createCurrent(P_uAnti, P_H, P_u, 664, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 225, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 575, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 828, check)
      call createCurrent(P_Z, P_A, P_Z, P_A, 1198, check)
      call createCurrent(P_A, P_H, P_WMinus, P_GPlus, 527, check)
      call createCurrent(P_g, P_g, P_A, P_g, 1221, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 337, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 165, check)
      call createCurrent(P_H, P_d, P_dAnti, 462, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 791, check)
      call createCurrent(P_s, P_H, P_sAnti, 818, check)
      call createCurrent(P_cAnti, P_c, 1090, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 718, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 926, check)
      call createCurrent(P_Z, P_GMinus, P_H, P_WPlus, 403, check)
      call createCurrent(P_muPlus, P_H, P_muMinus, 748, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 153, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 899, check)
      call createCurrent(P_A, P_nu_eAnti, P_nu_e, 1112, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 946, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 347, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 562, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_H, 904, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 697, check)
      call createCurrent(P_H, P_GMinus, P_H, P_GPlus, 901, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, 82, check)
      call createCurrent(P_G0, P_tAnti, P_t, 1, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 933, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 122, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 262, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 736, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 490, check)
      call createCurrent(P_g, P_g, P_g, P_g, 1002, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, P_H, 405, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 686, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 841, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, P_H, 587, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 275, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 104, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 762, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, 4, check)
      call createCurrent(P_cAnti, P_c, P_G0, 541, check)
      call createCurrent(P_dAnti, P_d, P_g, 298, check)
      call createCurrent(P_Z, P_H, P_G0, 896, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 584, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_A, 164, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 526, check)
      call createCurrent(P_bAnti, P_g, P_b, 604, check)
      call createCurrent(P_b, P_Z, P_bAnti, 38, check)
      call createCurrent(P_d, P_dAnti, P_G0, 532, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 237, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_A, 593, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 675, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 154, check)
      call createCurrent(P_u, P_uAnti, 1100, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 1038, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 476, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 1245, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 1005, check)
      call createCurrent(P_b, P_bAnti, P_Z, 68, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 14, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 354, check)
      call createCurrent(P_muMinus, P_H, P_muPlus, 796, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 103, check)
      call createCurrent(P_A, P_H, P_GPlus, P_WMinus, 409, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 378, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 98, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 382, check)
      call createCurrent(P_Z, P_Z, 1071, check)
      call createCurrent(P_s, P_sAnti, P_g, 699, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 1148, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 117, check)
      call createCurrent(P_H, P_ghZ, P_ghZAnti, 893, check)
      call createCurrent(P_sAnti, P_s, P_Z, 565, check)
      call createCurrent(P_uAnti, P_Z, P_u, 800, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, 694, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_Z, 627, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 358, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 121, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 172, check)
      call createCurrent(P_g, P_uAnti, P_u, 336, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 8, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 442, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 1228, check)
      call createCurrent(P_g, P_g, 1128, check)
      call createCurrent(P_A, P_GPlus, P_H, P_WMinus, 601, check)
      call createCurrent(P_G0, P_s, P_sAnti, 947, check)
      call createCurrent(P_H, P_Z, P_Z, 820, check)
      call createCurrent(P_Z, P_H, P_Z, P_H, 621, check)
      call createCurrent(P_d, P_dAnti, 1072, check)
      call createCurrent(P_A, P_G0, P_A, P_G0, 1236, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 286, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 1167, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 1182, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 781, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 903, check)
      call createCurrent(P_Z, P_sAnti, P_s, 390, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 127, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghWm, 45, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 158, check)
      call createCurrent(P_H, P_eMinus, P_ePlus, 666, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_H, 746, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_H, 518, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 531, check)
      call createCurrent(P_H, P_G0, P_Z, 821, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 131, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 674, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 19, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 140, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 436, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 70, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 456, check)
      call createCurrent(P_WMinus, P_GPlus, 1140, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 629, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 905, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 709, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 438, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 81, check)
      call createCurrent(P_WMinus, P_WPlus, 1104, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 646, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 413, check)
      call createCurrent(P_G0, P_G0, P_A, P_A, 1231, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 1150, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 50, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 867, check)
      call createCurrent(P_A, P_A, P_Z, P_A, 1237, check)
      call createCurrent(P_g, P_H, P_g, 1204, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 653, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 917, check)
      call createCurrent(P_H, P_H, P_GMinus, P_GPlus, 94, check)
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 577, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 406, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, 494, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 426, check)
      call createCurrent(P_G0, P_d, P_dAnti, 299, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 689, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 514, check)
      call createCurrent(P_bAnti, P_G0, P_b, 439, check)
      call createCurrent(P_H, P_Z, P_A, P_H, 1081, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 780, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 671, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 745, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 226, check)
      call createCurrent(P_H, P_Z, P_G0, 715, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, 393, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 970, check)
      call createCurrent(P_A, P_nu_e, P_nu_eAnti, 1062, check)
      call createCurrent(P_c, P_cAnti, P_H, 855, check)
      call createCurrent(P_u, P_uAnti, P_A, 546, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 641, check)
      call createCurrent(P_Z, P_H, P_H, P_A, 1078, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 910, check)
      call createCurrent(P_Z, P_Z, P_A, P_Z, 1170, check)
      call createCurrent(P_Z, P_cAnti, P_c, 489, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 749, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 277, check)
      call createCurrent(P_nu_eAnti, P_A, P_nu_e, 1086, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 611, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 761, check)
      call createCurrent(P_bAnti, P_Z, P_b, 846, check)
      call createCurrent(P_H, P_G0, P_G0, P_H, 105, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 1014, check)
      call createCurrent(P_A, P_Z, P_G0, P_G0, 1129, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 202, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_A, 454, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 530, check)
      call createCurrent(P_WMinus, P_H, P_A, P_GPlus, 864, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 612, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 515, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 617, check)
      call createCurrent(P_cAnti, P_H, P_c, 374, check)
      call createCurrent(P_d, P_dAnti, P_A, 663, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 937, check)
      call createCurrent(P_A, P_Z, 1118, check)
      call createCurrent(P_Z, P_H, P_WMinus, P_GPlus, 522, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, P_H, 940, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 181, check)
      call createCurrent(P_G0, P_G0, P_H, 120, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 90, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 434, check)
      call createCurrent(P_H, P_A, P_GPlus, P_WMinus, 376, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 214, check)
      call createCurrent(P_G0, P_A, P_A, P_G0, 1176, check)
      call createCurrent(P_cAnti, P_c, P_A, 384, check)
      call createCurrent(P_eMinus, P_ePlus, 1136, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 445, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 856, check)
      call createCurrent(P_c, P_cAnti, 1066, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 848, check)
      call createCurrent(P_H, P_A, P_Z, 1124, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 505, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 506, check)
      call createCurrent(P_H, P_muPlus, P_muMinus, 422, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 143, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 556, check)
      call createCurrent(P_s, P_sAnti, P_Z, 458, check)
      call createCurrent(P_WPlus, P_WMinus, 1105, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 216, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 765, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_H, 543, check)
      call createCurrent(P_H, P_H, P_H, P_H, 24, check)
      call createCurrent(P_nu_tauAnti, P_A, P_nu_tau, 1057, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 256, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 1205, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_H, 334, check)
      call createCurrent(P_Z, P_Z, P_H, P_H, 241, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 1193, check)
      call createCurrent(P_H, P_A, P_A, P_H, 1230, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 571, check)
      call createCurrent(P_G0, P_Z, P_A, P_G0, 1122, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 264, check)
      call createCurrent(P_Z, P_A, P_A, P_Z, 1241, check)
      call createCurrent(P_g, P_s, P_sAnti, 461, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, 244, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 615, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 249, check)
      call createCurrent(P_H, P_H, P_A, P_A, 1177, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 111, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 389, check)
      call createCurrent(P_b, P_bAnti, 1095, check)
      call createCurrent(P_H, P_Z, P_H, P_Z, 958, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 649, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 679, check)
      call createCurrent(P_tauMinus, P_tauPlus, 1065, check)
      call createCurrent(P_WMinus, P_A, P_H, P_GPlus, 651, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 997, check)
      call createCurrent(P_t, P_tAnti, 1064, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 586, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 802, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 591, check)
      call createCurrent(P_c, P_A, P_cAnti, 395, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 652, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 307, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 788, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 566, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 263, check)
      call createCurrent(P_dAnti, P_d, P_H, 367, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 701, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_H, 645, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 519, check)
      call createCurrent(P_d, P_G0, P_dAnti, 464, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 53, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 3, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 640, check)
      call createCurrent(P_A, P_H, P_A, 1239, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, 561, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 23, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 370, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 69, check)
      call createCurrent(P_Z, P_A, P_H, 1080, check)
      call createCurrent(P_bAnti, P_b, 1093, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 425, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 221, check)
      call createCurrent(P_A, P_H, P_H, P_Z, 1121, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 605, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 793, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 1147, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 960, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 634, check)
      call createCurrent(P_uAnti, P_u, P_A, 0, check)
      call createCurrent(P_tAnti, P_G0, P_t, 293, check)
      call createCurrent(P_A, P_tAnti, P_t, 865, check)
      call createCurrent(P_GPlus, P_A, P_H, P_WMinus, 951, check)
      call createCurrent(P_t, P_G0, P_tAnti, 551, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 950, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 139, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 423, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 1033, check)
      call createCurrent(P_t, P_tAnti, P_Z, 190, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 832, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 203, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 338, check)
      call createCurrent(P_tAnti, P_Z, P_t, 475, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 1006, check)
      call createCurrent(P_tauMinus, P_H, P_tauPlus, 733, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 12, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 1043, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 60, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 95, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 258, check)
      call createCurrent(P_Z, P_d, P_dAnti, 401, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 740, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 843, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 215, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 1194, check)
      call createCurrent(P_d, P_dAnti, P_H, 806, check)
      call createCurrent(P_Z, P_WMinus, P_H, P_GPlus, 753, check)
      call createCurrent(P_c, P_cAnti, P_G0, 573, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 1213, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 411, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 630, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 300, check)
      call createCurrent(P_b, P_bAnti, P_g, 357, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 346, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 97, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 581, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 567, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 325, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 1209, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 914, check)
      call createCurrent(P_uAnti, P_g, P_u, 650, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 330, check)
      call createCurrent(P_A, P_s, P_sAnti, 253, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 96, check)
      call createCurrent(P_b, P_A, P_bAnti, 492, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 827, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 816, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 1034, check)
      call createCurrent(P_H, P_ePlus, P_eMinus, 101, check)
      call createCurrent(P_WPlus, P_H, P_Z, P_GMinus, 285, check)
      call createCurrent(P_g, P_c, P_cAnti, 372, check)
      call createCurrent(P_bAnti, P_b, P_Z, 1035, check)
      call createCurrent(P_g, P_A, P_g, P_g, 1242, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 448, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 1009, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 813, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 296, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_H, 757, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 37, check)
      call createCurrent(P_A, P_H, P_Z, 1079, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, P_H, 348, check)
      call createCurrent(P_A, P_H, P_WPlus, P_GMinus, 909, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 27, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 314, check)
      call createCurrent(P_g, P_t, P_tAnti, 78, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 955, check)
      call createCurrent(P_H, P_tAnti, P_t, 860, check)
      call createCurrent(P_g, P_A, P_A, P_g, 1160, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 775, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 65, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 728, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 1232, check)
      call createCurrent(P_sAnti, P_Z, P_s, 114, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 420, check)
      call createCurrent(P_A, P_Z, P_H, 1114, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 1192, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 10, check)
      call createCurrent(P_GMinus, P_WPlus, 1052, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 211, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 46, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 695, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 363, check)
      call createCurrent(P_G0, P_H, P_G0, P_H, 932, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 245, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 578, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 268, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 545, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 204, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 696, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 408, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 119, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_A, 280, check)
      call createCurrent(P_u, P_uAnti, P_Z, 252, check)
      call createCurrent(P_GPlus, P_H, P_Z, P_WMinus, 491, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 1203, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, 56, check)
      call createCurrent(P_GMinus, P_H, P_Z, P_WPlus, 386, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 369, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 703, check)
      call createCurrent(P_A, P_A, P_G0, P_G0, 1186, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 635, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 62, check)
      call createCurrent(P_H, P_WPlus, P_Z, P_GMinus, 32, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 948, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 508, check)
      call createCurrent(P_ePlus, P_H, P_eMinus, 28, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 938, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 665, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 496, check)
      call createCurrent(P_A, P_t, P_tAnti, 536, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 355, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 361, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 886, check)
      call createCurrent(P_u, P_H, P_uAnti, 344, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 659, check)
      call createCurrent(P_Z, P_tAnti, P_t, 725, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 343, check)
      call createCurrent(P_g, P_b, P_bAnti, 113, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 259, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 989, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 539, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 257, check)
      call createCurrent(P_G0, P_G0, P_Z, P_A, 1092, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 51, check)
      call createCurrent(P_Z, P_s, P_sAnti, 236, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 735, check)
      call createCurrent(P_Z, P_t, P_tAnti, 109, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 595, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_A, 685, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 205, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 368, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 707, check)
      call createCurrent(P_c, P_H, P_cAnti, 485, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 961, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 692, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 737, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 415, check)
      call createCurrent(P_sAnti, P_s, P_g, 936, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_H, 831, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 417, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 582, check)
      call createCurrent(P_A, P_H, P_A, P_H, 1171, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 1011, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 754, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 842, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 33, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 135, check)
      call createCurrent(P_H, P_GPlus, P_H, P_GMinus, 387, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 1146, check)
      call createCurrent(P_bAnti, P_A, P_b, 687, check)
      call createCurrent(P_A, P_nu_tauAnti, P_nu_tau, 1049, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_H, 163, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 495, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 1214, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 176, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 906, check)
      call createCurrent(P_b, P_g, P_bAnti, 805, check)
      call createCurrent(P_tAnti, P_t, P_g, 453, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 77, check)
      call createCurrent(P_d, P_H, P_dAnti, 59, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 1015, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, P_H, 620, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 999, check)
      call createCurrent(P_Z, P_H, P_A, 1055, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 550, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 971, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 870, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 477, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 747, check)
      call createCurrent(P_G0, P_A, P_G0, P_Z, 1141, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 931, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, 750, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 553, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 743, check)
      call createCurrent(P_H, P_H, P_g, P_g, 1216, check)
      call createCurrent(P_G0, P_t, P_tAnti, 731, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 655, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 157, check)
      call createCurrent(P_sAnti, P_s, P_G0, 552, check)
      call createCurrent(P_s, P_sAnti, P_G0, 441, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 364, check)
      call createCurrent(P_H, P_Z, P_GPlus, P_WMinus, 416, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 544, check)
      call createCurrent(P_A, P_GMinus, P_H, P_WPlus, 287, check)
      call createCurrent(P_g, P_d, P_dAnti, 702, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 351, check)
      call createCurrent(P_s, P_G0, P_sAnti, 845, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 742, check)
      call createCurrent(P_u, P_G0, P_uAnti, 366, check)
      call createCurrent(P_H, P_A, P_GMinus, P_WPlus, 132, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 811, check)
      call createCurrent(P_c, P_G0, P_cAnti, 920, check)
      call createCurrent(P_G0, P_G0, 1053, check)
      call createCurrent(P_g, P_g, P_g, 473, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 385, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, 676, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, 85, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 292, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 188, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 854, check)
      call createCurrent(P_uAnti, P_u, P_Z, 729, check)
      call createCurrent(P_G0, P_cAnti, P_c, 1008, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, 362, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 72, check)
      call createCurrent(P_A, P_G0, P_G0, P_Z, 1070, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, 150, check)
      call createCurrent(P_G0, P_sAnti, P_s, 513, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 560, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 677, check)
      call createCurrent(P_GPlus, P_Z, P_H, P_WMinus, 559, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 1013, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 123, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 944, check)
      call createCurrent(P_H, P_dAnti, P_d, 240, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, 817, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 607, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 481, check)
      call createCurrent(P_GMinus, P_H, P_H, P_GPlus, 239, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 424, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 207, check)
      call createCurrent(P_A, P_Z, P_A, P_Z, 1190, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_H, 616, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 179, check)
      call createCurrent(P_H, P_u, P_uAnti, 162, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 568, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 858, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 752, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 557, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 622, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 558, check)
      call createCurrent(P_GMinus, P_Z, P_H, P_WPlus, 987, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 474, check)
      call createCurrent(P_H, P_A, P_G0, 1103, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 1027, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 1184, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 807, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_H, 915, check)
      call createCurrent(P_H, P_s, P_sAnti, 569, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 232, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 66, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 698, check)
      call createCurrent(P_H, P_Z, P_WMinus, P_GPlus, 463, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 106, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 349, check)
      call createCurrent(P_Z, P_H, P_GMinus, P_WPlus, 978, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 168, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 660, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 421, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 898, check)
      call createCurrent(P_WMinus, P_Z, P_H, P_GPlus, 487, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 147, check)
      call createCurrent(P_g, P_dAnti, P_d, 535, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 594, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 331, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_H, 242, check)
      call createCurrent(P_bAnti, P_b, P_H, 868, check)
      call createCurrent(P_eMinus, P_ePlus, P_H, 1030, check)
      call createCurrent(P_d, P_Z, P_dAnti, 67, check)
      call createCurrent(P_A, P_bAnti, P_b, 273, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 57, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 75, check)
      call createCurrent(P_g, P_bAnti, P_b, 288, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 229, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 321, check)
      call createCurrent(P_G0, P_G0, P_A, P_Z, 1088, check)
      call createCurrent(P_b, P_bAnti, P_H, 885, check)
      call createCurrent(P_t, P_A, P_tAnti, 887, check)
      call createCurrent(P_ePlus, P_eMinus, 1130, check)
      call createCurrent(P_H, P_WMinus, P_Z, P_GPlus, 939, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 1189, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_A, 804, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 972, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 410, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 564, check)
      call createCurrent(P_G0, P_Z, P_H, 844, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 767, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 1229, check)
      call createCurrent(P_A, P_A, P_g, P_g, 1181, check)
      call createCurrent(P_cAnti, P_c, P_Z, 599, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 996, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 510, check)
      call createCurrent(P_H, P_GMinus, P_Z, P_WPlus, 1000, check)
      call createCurrent(P_Z, P_A, 1106, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 391, check)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, 682, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 656, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 21, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 529, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 787, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 691, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 414, check)
      call createCurrent(P_c, P_cAnti, P_g, 783, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 872, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, P_H, 1041, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 688, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 128, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 849, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 1201, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 118, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 100, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 555, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 962, check)
      call createCurrent(P_G0, P_H, P_H, P_G0, 923, check)
      call createCurrent(P_bAnti, P_b, P_A, 269, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 922, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, 335, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 155, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 778, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 956, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 590, check)
      call createCurrent(P_muMinus, P_muPlus, 1131, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 339, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 838, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 900, check)
      call createCurrent(P_H, P_WMinus, P_A, P_GPlus, 945, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 161, check)
      call createCurrent(P_d, P_dAnti, P_g, 730, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 837, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 994, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 1238, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, 537, check)
      call createCurrent(P_Z, P_Z, P_Z, P_A, 1225, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 598, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 138, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 146, check)
      call createCurrent(P_A, P_nu_mu, P_nu_muAnti, 1091, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 169, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 305, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 589, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, P_H, 1040, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 1173, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_H, 704, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 350, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 628, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 254, check)
      call createCurrent(P_eMinus, P_H, P_ePlus, 1018, check)
      call createCurrent(P_G0, P_G0, P_H, P_H, 618, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 200, check)
      call createCurrent(P_A, P_H, P_Z, P_H, 1113, check)
      call createCurrent(P_g, P_H, P_g, P_H, 1195, check)
      call createCurrent(P_H, P_b, P_bAnti, 881, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 795, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 18, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 623, check)
      call createCurrent(P_Z, P_A, P_H, P_H, 1094, check)
      call createCurrent(P_dAnti, P_G0, P_d, 39, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 976, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 1026, check)
      call createCurrent(P_A, P_A, 1075, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 764, check)
      call createCurrent(P_H, P_WPlus, P_H, P_WMinus, 282, check)
      call createCurrent(P_Z, P_Z, P_H, 873, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 479, check)
      call createCurrent(P_A, P_WPlus, P_H, P_GMinus, 943, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 447, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 548, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 672, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 1107, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 766, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, 592, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 1174, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 875, check)
      call createCurrent(P_WMinus, P_H, P_H, P_WPlus, 468, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 227, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 317, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 186, check)
      call createCurrent(P_tAnti, P_t, P_G0, 196, check)
      call createCurrent(P_A, P_WMinus, P_H, P_GPlus, 585, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 500, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 894, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, 274, check)
      call createCurrent(P_tAnti, P_g, P_t, 482, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 40, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 597, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 880, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 126, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 251, check)
      call createCurrent(P_H, P_A, P_WPlus, P_GMinus, 17, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 734, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 373, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 852, check)
      call createCurrent(P_u, P_uAnti, P_g, 486, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 301, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_A, 1138, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 876, check)
      call createCurrent(P_GPlus, P_H, P_A, P_WMinus, 170, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 316, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 145, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 918, check)
      call createCurrent(P_Z, P_G0, 1050, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_H, 784, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 304, check)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, 1010, check)
      call createCurrent(P_tauPlus, P_H, P_tauMinus, 724, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 383, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_H, 825, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 624, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 517, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 965, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 440, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 973, check)
      call createCurrent(P_WPlus, P_GMinus, 1116, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 189, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 480, check)
      call createCurrent(P_u, P_g, P_uAnti, 228, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 889, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, 952, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 1235, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 219, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 79, check)
      call createCurrent(P_H, P_A, P_A, 1158, check)
      call createCurrent(P_G0, P_A, 1101, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, 308, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 1017, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 184, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 270, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 798, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_Z, 953, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 396, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 572, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 631, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 507, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 1169, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 1196, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 402, check)
      call createCurrent(P_b, P_H, P_bAnti, 521, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 1077, check)
      call createCurrent(P_H, P_c, P_cAnti, 928, check)
      call createCurrent(P_tAnti, P_A, P_t, 814, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_Z, 878, check)
      call createCurrent(P_Z, P_G0, P_A, P_G0, 1051, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 91, check)
      call createCurrent(P_cAnti, P_c, P_H, 911, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 869, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 175, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 1164, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 6, check)
      call createCurrent(P_u, P_Z, P_uAnti, 281, check)
      call createCurrent(P_H, P_ghWp, P_ghWpAnti, 668, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_H, 174, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 1211, check)
      call createCurrent(P_H, P_Z, P_A, 1109, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 1042, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 533, check)
      call createCurrent(P_nu_muAnti, P_A, P_nu_mu, 1097, check)
      call createCurrent(P_s, P_sAnti, P_A, 760, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 758, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 419, check)
      call createCurrent(P_H, P_Z, P_Z, P_H, 642, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, 600, check)
      call createCurrent(P_dAnti, P_d, P_G0, 125, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(4)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(5)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(9)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(17)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(18)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(19)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(20)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(22)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(23)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(24)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(25)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(27)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(28)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(44)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(45)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(46)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(47)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(48)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(49)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(50)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(52)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(53)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(54)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(55)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(58)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(64)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(67)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(71)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(73)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
